@@ -13,10 +13,6 @@ def installable_rhino_packages():
 
 @compas.plugins.plugin(category='install')
 def after_rhino_install(installed_packages):
-    # GH Components are not supported on non-Windows platforms
-    if not compas.is_windows():
-        return []
-
     if 'compas_fab' not in installed_packages:
         return []
 
@@ -26,10 +22,6 @@ def after_rhino_install(installed_packages):
 
 @compas.plugins.plugin(category='install')
 def after_rhino_uninstall(installed_packages):
-    # GH Components are not supported on non-Windows platforms
-    if not compas.is_windows():
-        return []
-
     if 'compas_fab' not in installed_packages:
         return []
 
